Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/pqlattice/__init__.py | 4 | 0 | 0 | 100%
src/pqlattice/integer/__init__.py | 6 | 0 | 0 | 100%
src/pqlattice/integer/_integer.py | 24 | 1 | 8 | 96%
src/pqlattice/integer/_modintring.py | 33 | 2 | 36 | 94%
src/pqlattice/integer/_modring.py | 32 | 5 | 40 | 84%
src/pqlattice/integer/_primality.py | 44 | 8 | 0 | 82%
src/pqlattice/integer/_primes.py | 1 | 0 | 0 | 100%
src/pqlattice/lattice/__init__.py | 16 | 4 | 0 | 75%
src/pqlattice/lattice/_bkz.py | 50 | 1 | 0 | 98%
src/pqlattice/lattice/_gso.py | 20 | 0 | 0 | 100%
src/pqlattice/lattice/_hkz.py | 6 | 0 | 0 | 100%
src/pqlattice/lattice/_lattice.py | 42 | 2 | 0 | 95%
src/pqlattice/lattice/_lll.py | 41 | 8 | 0 | 80%
src/pqlattice/lattice/_svp.py | 58 | 0 | 0 | 100%
src/pqlattice/lattice/embeddings.py | 2 | 0 | 0 | 100%
src/pqlattice/linalg/__init__.py | 8 | 1 | 0 | 88%
src/pqlattice/linalg/_linalg.py | 104 | 17 | 0 | 84%
src/pqlattice/linalg/_utils.py | 28 | 1 | 0 | 96%
src/pqlattice/polynomial/__init__.py | 4 | 0 | 0 | 100%
src/pqlattice/polynomial/_modpolyqring.py | 49 | 13 | 0 | 73%
src/pqlattice/polynomial/_modpolyring.py | 66 | 26 | 0 | 61%
src/pqlattice/polynomial/_poly.py | 59 | 14 | 0 | 76%
src/pqlattice/polynomial/poly.py | 2 | 0 | 0 | 100%
src/pqlattice/random/__init__.py | 6 | 0 | 0 | 100%
src/pqlattice/random/_distribution.py | 104 | 31 | 16 | 70%
src/pqlattice/random/_lattice.py | 24 | 0 | 0 | 100%
src/pqlattice/random/_lwe.py | 36 | 25 | 0 | 31%
src/pqlattice/random/_prime.py | 28 | 1 | 0 | 96%
src/pqlattice/random/distribution.py | 2 | 0 | 0 | 100%
src/pqlattice/typing/__init__.py | 3 | 0 | 0 | 100%
src/pqlattice/typing/_types.py | 11 | 2 | 0 | 82%
src/pqlattice/typing/_types_validator.py | 36 | 0 | 0 | 100%
Total | 949 | 162 | 100 | 83%

No items found using the specified filter.